%global modulename neutron_lbaas
%global servicename neutron-lbaas
%global type LBaaS
%global min_neutron_version 1:8.0.0

# rpm macro to create fake tempest plugin entrypoint
%define py2_entrypoint() \
egg_path=%{buildroot}%{python2_sitelib}/%{1}-*.egg-info \
tempest_egg_path=%{buildroot}%{python2_sitelib}/%{1}_tests.egg-info \
mkdir $tempest_egg_path \
echo %{1} >$tempest_egg_path/top_level.txt \
grep "tempest\\|Tempest" %{1}.egg-info/entry_points.txt >$tempest_egg_path/entry_points.txt \
sed -i "/tempest\\|Tempest/d" $egg_path/entry_points.txt \
cp -r $egg_path/PKG-INFO $tempest_egg_path \
sed -i "s/%{2}/%{1}_tests/g" $tempest_egg_path/PKG-INFO \
%nil

%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

Name:           openstack-%{servicename}
Version:        8.4.0
Release:        4%{?dist}
Epoch:          1
Summary:        Openstack Networking %{type} plugin

License:        ASL 2.0
URL:            http://launchpad.net/neutron/
Source0:        http://tarballs.openstack.org/%{servicename}/%{servicename}-%{version}%{?milestone}.tar.gz
Source1:        %{servicename}-agent.service
Source2:        %{servicename}v2-agent.service

Source3:        %{servicename}-dist.conf

#
# patches_ignore=DROP-IN-RPM
# patches_base=+2
#
Patch0001: 0001-Rename-private_key-tests.patch
Patch0002: 0002-Skip-pylint-errors-in-radware-driver-modules.patch
Patch0003: 0003-Pass-network-MTU-into-namespace-driver.patch
Patch0004: 0004-Tests-helper-function-_send_requests-should-catch-so.patch
Patch0005: 0005-Implements-ProcessMonitor-in-the-haproxy-driver.patch
Patch0006: 0006-Update-quota-tests-to-register-quota-resources.patch
Patch0007: 0007-Add-support-to-update-members-in-LBaaS-extension.patch
Patch0008: 0008-Fixed-upper-constraints-file-link.patch
Patch0009: 0009-apply-whitespace-changes-to-adapt-setup.cfg-from-rel.patch
Patch0010: 0010-Fix-tempest-scenario-tests.patch
Patch0011: 0011-Plugin-to-run-neutron-lbaas-tests-with-tempest.patch

BuildArch:      noarch
BuildRequires:  python-devel
BuildRequires:  python-barbicanclient >= 4.0.0
BuildRequires:  python-neutron >= %{min_neutron_version}
BuildRequires:  python-neutron-lib
BuildRequires:  python-pbr
BuildRequires:  python-pyasn1
BuildRequires:  python-pyasn1-modules
BuildRequires:  python-setuptools
BuildRequires:  systemd-units
BuildRequires:	git
# Test deps
BuildRequires:  python-cryptography

Requires:       python-%{servicename} = %{epoch}:%{version}-%{release}
Requires:       openstack-neutron >= %{min_neutron_version}

%description
This is a %{type} service plugin for Openstack Neutron (Networking) service.


%package -n python-%{servicename}
Summary:        Neutron %{type} Python libraries
Group:          Applications/System

Requires:       python-neutron >= %{min_neutron_version}
Requires:       python-barbicanclient >= 4.0.0
Requires:       python-pyasn1
Requires:       python-pyasn1-modules
Requires:       pyOpenSSL


%description -n python-%{servicename}
This is a %{type} service plugin for Openstack Neutron (Networking) service.

This package contains the Neutron %{type} Python library.


%package -n python-%{servicename}-tests
Summary:        Neutron %{type} tests
Group:          Applications/System

Requires:       python-%{servicename} = %{epoch}:%{version}-%{release}


%description -n python-%{servicename}-tests
This is a %{type} service plugin for Openstack Neutron (Networking) service.

This package contains Neutron %{type} test files.


%prep
%autosetup -n %{servicename}-%{upstream_version} -S git

# Let's handle dependencies ourselves
rm -f requirements.txt

# Kill egg-info in order to generate new SOURCES.txt
rm -rf neutron_lbaas.egg-info

%build
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py build

# Generate configuration files
PYTHONPATH=. tools/generate_config_file_samples.sh
find etc -name *.sample | while read filename
do
    filedir=$(dirname $filename)
    file=$(basename $filename .sample)
    mv ${filename} ${filedir}/${file}
done

# Loop through values in neutron-lbaas-dist.conf and make sure that the values
# are substituted into the lbaas_agent.ini as comments.
while read name eq value; do
  if [ -n "$name" -a -n "$value" ]; then
    sed -ri "0,/^(#)? *$name *=/{s!\(^(#)? *$name *=\).*!\1 $value!}" etc/lbaas_agent.ini
  fi
done < %{SOURCE3}


%install
export PBR_VERSION=%{version}
export SKIP_PIP_INSTALL=1
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}

# Move rootwrap files to proper location
install -d -m 755 %{buildroot}%{_datarootdir}/neutron/rootwrap
mv %{buildroot}/usr/etc/neutron/rootwrap.d/*.filters %{buildroot}%{_datarootdir}/neutron/rootwrap

# Move config files to proper location
install -d -m 755 %{buildroot}%{_sysconfdir}/neutron

# The generated config files are not moved automatically by setup.py
mv etc/*.ini etc/*.conf %{buildroot}%{_sysconfdir}/neutron

# Install systemd units
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{servicename}-agent.service
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{servicename}v2-agent.service

# Install dist conf
install -p -D -m 640 %{SOURCE3} %{buildroot}%{_datadir}/neutron/%{servicename}-dist.conf

# Create configuration directories that can be populated by users with custom *.conf files
mkdir -p %{buildroot}/%{_sysconfdir}/neutron/conf.d/%{servicename}-agent
mkdir -p %{buildroot}/%{_sysconfdir}/neutron/conf.d/%{servicename}v2-agent

# Make sure neutron-server loads new configuration file
mkdir -p %{buildroot}/%{_datadir}/neutron/server
ln -s %{_sysconfdir}/neutron/%{modulename}.conf %{buildroot}%{_datadir}/neutron/server/%{modulename}.conf

%py2_entrypoint %{modulename} %{servicename}

%post
%systemd_post %{servicename}-agent.service
%systemd_post %{servicename}v2-agent.service


%preun
%systemd_preun %{servicename}-agent.service
%systemd_preun %{servicename}v2-agent.service


%postun
%systemd_postun_with_restart %{servicename}-agent.service
%systemd_postun_with_restart %{servicename}v2-agent.service


%files
%license LICENSE
%doc AUTHORS CONTRIBUTING.rst README.rst
%{_bindir}/%{servicename}-agent
%{_bindir}/%{servicename}v2-agent
%{_unitdir}/%{servicename}-agent.service
%{_unitdir}/%{servicename}v2-agent.service
%{_datarootdir}/neutron/rootwrap/lbaas-haproxy.filters
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/lbaas_agent.ini
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/neutron_lbaas.conf
%config(noreplace) %attr(0640, root, neutron) %{_sysconfdir}/neutron/services_lbaas.conf
%dir %{_sysconfdir}/neutron/conf.d
%dir %{_sysconfdir}/neutron/conf.d/%{servicename}-agent
%dir %{_sysconfdir}/neutron/conf.d/%{servicename}v2-agent
%attr(-, root, neutron) %{_datadir}/neutron/%{servicename}-dist.conf
%{_datadir}/neutron/server/%{modulename}.conf


%files -n python-%{servicename}
%{python2_sitelib}/%{modulename}
%{python2_sitelib}/%{modulename}-%{version}-py%{python2_version}.egg-info
%exclude %{python2_sitelib}/%{modulename}/tests


%files -n python-%{servicename}-tests
%{python2_sitelib}/%{modulename}/tests
%{python2_sitelib}/%{modulename}_tests.egg-info

%changelog
* Thu Feb 22 2018 Chandan Kumar <chkumar@redhat.com> 1:8.4.0-4
- Added macro to create tempest plugin fake entrypoint

* Tue Feb 20 2018 Carlos Goncalves <cgoncalves@redhat.com> 1:8.4.0-3
- Plugin to run neutron-lbaas tests with tempest (rhbz#1526098)
- Fix tempest scenario tests (rhbz#1526098)
- apply whitespace changes to adapt setup.cfg from release tarball (rhbz#1526098)
- Fixed upper constraints file link

* Thu Aug 24 2017 Nir Magnezi <nmagnezi@redhat.com> 1:8.4.0-2
- Add support to update members in LBaaS extension
- Update quota tests to register quota resources (rhbz#1482599)

* Mon Jul 17 2017 Nir Magnezi <nmagnezi@redhat.com> 1:8.4.0-1
- Update to 8.4.0 (rhbz#1343937)

* Mon Jun 19 2017 Nir Magnezi <nmagnezi@redhat.com> 1:8.1.0-3
- Implements ProcessMonitor in the haproxy driver (rhbz#1431152)
- Tests helper function _send_requests should catch socket.error (rhbz#1462738)

* Mon Dec 26 2016 Nir Magnezi <nmagnezi@redhat.com> 1:8.1.0-2
- Pass network MTU into namespace driver (rhbz#1405443)

* Mon May 23 2016 Ihar Hrachyshka <ihrachys@redhat.com> 1:8.1.0-1.el7
- Update to 8.1.0

* Sat Apr 09 2016 Alan Pevec <apevec AT redhat.com> 8.0.0-1
- Update to Mitaka GA

* Thu Mar 24 2016 RDO <rdo-list@redhat.com> 8.0.0-0.1.0rc1
- RC1 Rebuild for Mitaka rc1
